pub struct SendMessageRequest {
pub to: Recipients,
pub signature: Option<String>,
pub template_id: Option<String>,
pub template_data: Option<BTreeMap<String, Value>>,
pub content: Option<String>,
pub text: Option<String>,
}Expand description
Parameters accepted by sms.message.send.
Fields
to: RecipientsDestination phone number or phone numbers in E.164 format.
signature: Option<String>Message signature placed before or after content, depending on locale.
template_id: Option<String>Unimatrix message template ID.
template_data: Option<BTreeMap<String, Value>>Values substituted into the selected template.
content: Option<String>Message content without a signature.
text: Option<String>Complete message text, including any required signature.
Implementations
Sourceimpl SendMessageRequest
impl SendMessageRequest
Sourcepub fn text(to: impl Into<Recipients>, text: impl Into<String>) -> Self
pub fn text(to: impl Into<Recipients>, text: impl Into<String>) -> Self
Creates a request whose text already includes the message signature.
Sourcepub fn template(
to: impl Into<Recipients>,
signature: impl Into<String>,
template_id: impl Into<String>,
) -> Self
pub fn template( to: impl Into<Recipients>, signature: impl Into<String>, template_id: impl Into<String>, ) -> Self
Creates a request using a message template.
Sourcepub fn content(
to: impl Into<Recipients>,
signature: impl Into<String>,
content: impl Into<String>,
) -> Self
pub fn content( to: impl Into<Recipients>, signature: impl Into<String>, content: impl Into<String>, ) -> Self
Creates a request using raw content and a separate signature.
Sourcepub fn with_template_data(self, data: BTreeMap<String, Value>) -> Self
pub fn with_template_data(self, data: BTreeMap<String, Value>) -> Self
Adds data used by a message template.