pub enum UniError {
Api {
code: String,
message: String,
status: StatusCode,
request_id: Option<String>,
body: Option<Value>,
},
Http {
status: StatusCode,
message: String,
request_id: Option<String>,
body: Option<Value>,
},
Transport(Error),
Configuration(String),
InvalidResponse {
status: StatusCode,
request_id: Option<String>,
message: String,
body: String,
},
}Expand description
Errors produced while configuring the client or calling the API.
Variants
Api
An API response contained a non-zero business error code.
Fields

status: StatusCodeHTTP status of the response.
Http
The server returned a non-successful HTTP status without an API error.
Fields

status: StatusCodeNon-successful HTTP status.
Transport(Error)
A transport-level error occurred.
Configuration(String)
The endpoint URL or client configuration was invalid.
InvalidResponse
A response could not be decoded according to the API schema.
Implementations